@@ -1,5 +1,7 @@
 from __future__ import unicode_literals
-from django.conf.urls import url, include
+
+from django.conf.urls import include, url
+
 from . import views
 
 app_name = "standingsrequests"
@@ -7,7 +9,12 @@ app_name = "standingsrequests"
 local_urlpatterns = [
     url(r"^$", views.index_view, name="index"),
     url(r"^create_requests", views.create_requests, name="create_requests"),
-    url(r"^request_entities$", views.partial_request_entities, name="request_entities"),
+    url(r"^request_characters$", views.request_characters, name="request_characters"),
+    url(
+        r"^request_corporations$",
+        views.request_corporations,
+        name="request_corporations",
+    ),
     url(
         r"^request_pilot_standing/(?P<character_id>\d+)/",
         views.request_pilot_standing,
